==> ackee-frontend-toolkit-0.13.0.tgz: package/lib/modules/forms/stories/fields.story.js <==
'use strict';

require('babel-polyfill');

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _reactRedux = require('react-redux');

var _reduxForm = require('redux-form');

var _moment = require('moment');

var _moment2 = _interopRequireDefault(_moment);

var _react3 = require('@storybook/react');

var _ = require('..');

var _configureStore = require('../../../../stories/configureStore');

var _configureStore2 = _interopRequireDefault(_configureStore);

var _Form = require('./Form');

var _Form2 = _interopRequireDefault(_Form);

require('./fields.story.scss');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var reducers = {
    form: _reduxForm.reducer
};

var store = (0, _configureStore2.default)({}, reducers);

(0, _react3.storiesOf)('Modules|forms/FormFields/Text', module).addDecorator(function (story) {
    return _react2.default.createElement(
        _reactRedux.Provider,
        { store: store },
        _react2.default.createElement(
            _Form2.default,
            null,
            story()
        )
    );
}).add('TextField', function () {
    return _react2.default.createElement(_.TextField, { name: 'textField', label: 'Text field' });
}).add('TextField: type password', function () {
    return _react2.default.createElement(_.TextField, { name: 'passwordField', type: 'password', label: 'Password field' });
}).add('TextAreaField', function () {
    return _react2.default.createElement(_.TextAreaField, { name: 'textAreaField', label: 'Textarea field' });
});

(0, _react3.storiesOf)('Modules|forms/FormFields/Number', module).addDecorator(function (story) {
    return _react2.default.createElement(
        _reactRedux.Provider,
        { store: store },
        _react2.default.createElement(
            _Form2.default,
            null,
            story()
        )
    );
}).add('NumberField', function () {
    return _react2.default.createElement(_.NumberField, { name: 'numberField', label: 'Number field' });
});

(0, _react3.storiesOf)('Modules|forms/FormFields/Select', module).addDecorator(function (story) {
    return _react2.default.createElement(
        _reactRedux.Provider,
        { store: store },
        _react2.default.createElement(
            _Form2.default,
            { initialValues: { multiSelectField: ['5', '6'] } },
            story()
        )
    );
}).add('SelectField', function () {
    return _react2.default.createElement(_.SelectField, {
        name: 'selectField',
        label: 'Select field',
        placeholder: 'Select a value',
        options: Array.from(Array(10).keys()).map(function (index) {
            return {
                value: index,
                label: 'Option #' + index,
                key: index
            };
        })
    });
}).add('SelectField: multiple values', function () {
    return _react2.default.createElement(_.SelectField, {
        name: 'multiSelectField',
        label: 'Multple value Select field',
        mode: 'multiple',
        options: Array.from(Array(10).keys()).map(function (index) {
            return {
                value: index,
                label: 'Option #' + index,
                key: index
            };
        })
    });
});

(0, _react3.storiesOf)('Modules|forms/FormFields/Checkbox', module).addDecorator(function (story) {
    return _react2.default.createElement(
        _reactRedux.Provider,
        { store: store },
        _react2.default.createElement(
            _Form2.default,
            { initialValues: { checkboxGroupField: ['selected'] } },
            story()
        )
    );
}).add('CheckboxGroupField', function () {
    return _react2.default.createElement(_.CheckboxGroupField, {
        name: 'checkboxGroupField',
        label: 'Checkbox group field',
        options: [{
            label: 'Selected box',
            value: 'selected'
        }, {
            label: 'Disabled box',
            value: 'disabled',
            disabled: true
        }, {
            label: 'Unselected box',
            value: 'unSelected'
        }]
    });
});

(0, _react3.storiesOf)('Modules|forms/FormFields/Radio', module).addDecorator(function (story) {
    return _react2.default.createElement(
        _reactRedux.Provider,
        { store: store },
        _react2.default.createElement(
            _Form2.default,
            { initialValues: { radioField: 1 } },
            story()
        )
    );
}).add('RadioField', function () {
    return _react2.default.createElement(_.RadioField, {
        name: 'checkboxField',
        label: 'Select field',
        options: [{
            label: 'First',
            value: 1
        }, {
            label: 'Second',
            value: 2,
            disabled: true
        }, {
            label: 'Third',
            value: 3
        }]
    });
});

(0, _react3.storiesOf)('Modules|forms/FormFields/Switch', module).addDecorator(function (story) {
    return _react2.default.createElement(
        _reactRedux.Provider,
        { store: store },
        _react2.default.createElement(
            _Form2.default,
            { initialValues: { checkedSwitchField: true } },
            story()
        )
    );
}).add('SwitchField', function () {
    return _react2.default.createElement(_.SwitchField, { name: 'switchField', label: 'Switch field' });
}).add('CheckedSwitchField', function () {
    return _react2.default.createElement(_.SwitchField, { name: 'checkedSwitchField', label: 'Checked switch field', checkedChildren: '+', unCheckedChildren: '-' });
});

(0, _react3.storiesOf)('Modules|forms/FormFields/Slider', module).addDecorator(function (story) {
    return _react2.default.createElement(
        _reactRedux.Provider,
        { store: store },
        _react2.default.createElement(
            _Form2.default,
            { initialValues: { sliderField: 50 } },
            story()
        )
    );
}).add('SliderField', function () {
    return _react2.default.createElement(_.SliderField, { name: 'sliderField', label: 'Slider field', min: 0, max: 100 });
}).add('MarkedSliderField', function () {
    return _react2.default.createElement(_.SliderField, { name: 'markedSliderField', label: 'Marked slider field', min: 0, max: 100, marks: { 0: '0px', 50: '50px', 100: '100px' }, step: 5 });
});

(0, _react3.storiesOf)('Modules|forms/FormFields/DatePicker', module).addDecorator(function (story) {
    return _react2.default.createElement(
        _reactRedux.Provider,
        { store: store },
        _react2.default.createElement(
            _Form2.default,
            { initialValues: { datePicker: (0, _moment2.default)().toISOString() } },
            story()
        )
    );
}).add('DatePicker', function () {
    return _react2.default.createElement(_.DatePickerField, { name: 'datePicker', label: 'Datepicker Field', displayFormat: 'DD/mm/YYYY' });
});

(0, _react3.storiesOf)('Modules|forms/FormFields/TimePicker', module).addDecorator(function (story) {
    return _react2.default.createElement(
        _reactRedux.Provider,
        { store: store },
        _react2.default.createElement(
            _Form2.default,
            null,
            story()
        )
    );
}).add('TimePicker', function () {
    return _react2.default.createElement(_.TimePickerField, { name: 'timePicker', label: 'Timepicker Field', displayFormat: 'H:mm:ss' });
});

==> ackee-frontend-toolkit-0.16.1.tgz: package/lib/modules/forms/stories/fields.story.js <==
'use strict';

require('babel-polyfill');

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _reactIntl = require('react-intl');

var _reactRedux = require('react-redux');

var _reduxForm = require('redux-form');

var _moment = require('moment');

var _moment2 = _interopRequireDefault(_moment);

var _react3 = require('@storybook/react');

var _ = require('..');

var _configureStore = require('../../../../stories/configureStore');

var _configureStore2 = _interopRequireDefault(_configureStore);

var _Form = require('./Form');

var _Form2 = _interopRequireDefault(_Form);

require('./fields.story.scss');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var reducers = {
    form: _reduxForm.reducer
};

var store = (0, _configureStore2.default)({}, reducers);

(0, _react3.storiesOf)('Modules|forms/FormFields/Text', module).addDecorator(function (story) {
    return _react2.default.createElement(
        _reactRedux.Provider,
        { store: store },
        _react2.default.createElement(
            _Form2.default,
            null,
            story()
        )
    );
}).add('TextField', function () {
    return _react2.default.createElement(_.TextField, { name: 'textField', label: 'Text field' });
}).add('TextField: type password', function () {
    return _react2.default.createElement(_.TextField, {
        name: 'passwordField',
        type: 'password',
        label: 'Password field'
    });
}).add('TextAreaField', function () {
    return _react2.default.createElement(_.TextAreaField, { name: 'textAreaField', label: 'Textarea field' });
});

(0, _react3.storiesOf)('Modules|forms/FormFields/Number', module).addDecorator(function (story) {
    return _react2.default.createElement(
        _reactRedux.Provider,
        { store: store },
        _react2.default.createElement(
            _Form2.default,
            null,
            story()
        )
    );
}).add('NumberField', function () {
    return _react2.default.createElement(_.NumberField, { name: 'numberField', label: 'Number field' });
});

(0, _react3.storiesOf)('Modules|forms/FormFields/Select', module).addDecorator(function (story) {
    return _react2.default.createElement(
        _reactRedux.Provider,
        { store: store },
        _react2.default.createElement(
            _Form2.default,
            { initialValues: { multiSelectField: ['5', '6'] } },
            story()
        )
    );
}).add('SelectField', function () {
    return _react2.default.createElement(_.SelectField, {
        name: 'selectField',
        label: 'Select field',
        placeholder: 'Select a value',
        options: Array.from(Array(10).keys()).map(function (index) {
            return {
                value: index,
                label: 'Option #' + index,
                key: index
            };
        })
    });
}).add('SelectField: multiple values', function () {
    return _react2.default.createElement(_.SelectField, {
        name: 'multiSelectField',
        label: 'Multple value Select field',
        mode: 'multiple',
        options: Array.from(Array(10).keys()).map(function (index) {
            return {
                value: index,
                label: 'Option #' + index,
                key: index
            };
        })
    });
});

(0, _react3.storiesOf)('Modules|forms/FormFields/Checkbox', module).addDecorator(function (story) {
    return _react2.default.createElement(
        _reactRedux.Provider,
        { store: store },
        _react2.default.createElement(
            _Form2.default,
            { initialValues: { checkboxGroupField: ['selected'] } },
            story()
        )
    );
}).add('CheckboxGroupField', function () {
    return _react2.default.createElement(_.CheckboxGroupField, {
        name: 'checkboxGroupField',
        label: 'Checkbox group field',
        options: [{
            label: 'Selected box',
            value: 'selected'
        }, {
            label: 'Disabled box',
            value: 'disabled',
            disabled: true
        }, {
            label: 'Unselected box',
            value: 'unSelected'
        }]
    });
}).add('CheckboxGroupField: default values', function () {
    return _react2.default.createElement(_.CheckboxGroupField, {
        name: 'checkboxGroupFieldDefaultValue',
        label: 'Checkbox group field',
        defaultValue: ['val2'],
        options: [{
            label: 'Value 1',
            value: 'val1'
        }, {
            label: 'Value 2',
            value: 'val2'
        }]
    });
});

(0, _react3.storiesOf)('Modules|forms/FormFields/Radio', module).addDecorator(function (story) {
    return _react2.default.createElement(
        _reactRedux.Provider,
        { store: store },
        _react2.default.createElement(
            _Form2.default,
            { initialValues: { radioField: 1 } },
            story()
        )
    );
}).add('RadioField', function () {
    return _react2.default.createElement(_.RadioField, {
        name: 'checkboxField',
        label: 'Select field',
        options: [{
            label: 'First',
            value: 1
        }, {
            label: 'Second',
            value: 2,
            disabled: true
        }, {
            label: 'Third',
            value: 3
        }]
    });
});

(0, _react3.storiesOf)('Modules|forms/FormFields/Switch', module).addDecorator(function (story) {
    return _react2.default.createElement(
        _reactRedux.Provider,
        { store: store },
        _react2.default.createElement(
            _Form2.default,
            { initialValues: { checkedSwitchField: true } },
            story()
        )
    );
}).add('SwitchField', function () {
    return _react2.default.createElement(_.SwitchField, { name: 'switchField', label: 'Switch field' });
}).add('CheckedSwitchField', function () {
    return _react2.default.createElement(_.SwitchField, {
        name: 'checkedSwitchField',
        label: 'Checked switch field',
        checkedChildren: '+',
        unCheckedChildren: '-'
    });
});

(0, _react3.storiesOf)('Modules|forms/FormFields/Slider', module).addDecorator(function (story) {
    return _react2.default.createElement(
        _reactRedux.Provider,
        { store: store },
        _react2.default.createElement(
            _Form2.default,
            { initialValues: { sliderField: 50 } },
            story()
        )
    );
}).add('SliderField', function () {
    return _react2.default.createElement(_.SliderField, {
        name: 'sliderField',
        label: 'Slider field',
        min: 0,
        max: 100
    });
}).add('MarkedSliderField', function () {
    return _react2.default.createElement(_.SliderField, {
        name: 'markedSliderField',
        label: 'Marked slider field',
        min: 0,
        max: 100,
        marks: { 0: '0px', 50: '50px', 100: '100px' },
        step: 5
    });
});

var validateRequired = function validateRequired(fieldName) {
    return function (values, _ref) {
        var intl = _ref.intl;

        var errors = {};

        if (!values[fieldName]) {
            errors[fieldName] = intl.formatMessage({ id: 'field.validate.required' }, { name: fieldName });
        }

        return errors;
    };
};
var intlMessages = {
    'field.validate.required': 'Field {name} is required'
};

(0, _react3.storiesOf)('Modules|forms/FormFields/DatePicker', module).addDecorator(function (story) {
    return _react2.default.createElement(
        _reactRedux.Provider,
        { store: store },
        _react2.default.createElement(
            _reactIntl.IntlProvider,
            { locale: 'en', messages: intlMessages },
            story()
        )
    );
}).add('DatePicker', function () {
    return _react2.default.createElement(
        _Form2.default,
        { initialValues: { datePicker: (0, _moment2.default)().toISOString() } },
        _react2.default.createElement(_.DatePickerField, {
            name: 'datePicker',
            label: 'Datepicker Field',
            displayFormat: 'DD/MM/YYYY'
        })
    );
}).add('localized validation', function () {
    return _react2.default.createElement(
        _Form2.default,
        { initialValues: { datePicker: (0, _moment2.default)().toISOString() }, validate: validateRequired('datePicker') },
        _react2.default.createElement(_.DatePickerField, {
            name: 'datePicker',
            label: 'Datepicker Field with localized validation',
            displayFormat: 'DD/MM/YYYY'
        })
    );
});

(0, _react3.storiesOf)('Modules|forms/FormFields/TimePicker', module).addDecorator(function (story) {
    return _react2.default.createElement(
        _reactRedux.Provider,
        { store: store },
        _react2.default.createElement(
            _reactIntl.IntlProvider,
            { locale: 'en', messages: intlMessages },
            story()
        )
    );
}).add('TimePicker', function () {
    return _react2.default.createElement(
        _Form2.default,
        null,
        _react2.default.createElement(_.TimePickerField, {
            name: 'timePicker',
            label: 'Timepicker Field',
            displayFormat: 'H:mm:ss'
        })
    );
}).add('localized validation', function () {
    return _react2.default.createElement(
        _Form2.default,
        { validate: validateRequired('timePicker') },
        _react2.default.createElement(_.TimePickerField, {
            name: 'timePicker',
            label: 'Timepicker Field with localized validation',
            displayFormat: 'H:mm:ss'
        })
    );
});
